@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001, 2002 Zope Corporation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -11,8 +11,6 @@
 # FOR A PARTICULAR PURPOSE.
 ##############################################################################
 """Application Control Tests
-
-$Id: test_applicationcontrol.py 107926 2010-01-09 14:12:52Z faassen $
 """
 import unittest
 from zope.interface.verify import verifyObject
@@ -36,7 +34,7 @@ class Test(unittest.TestCase):
         assert_time = time.time()
         test_time = self._Test__new().getStartTime()
 
-        self.failUnless(abs(assert_time - test_time) < time_tolerance)
+        self.assertTrue(abs(assert_time - test_time) < time_tolerance)
 
 
 def test_suite():
